#[repr(u8)]pub enum BTreeTryCloneError {
KeyCloningError = 1,
ValueCloningError = 2,
OtherError = 3,
}Expand description
Represents possible errors when trying to clone a BTree.
Variants
KeyCloningError = 1
The key cloning failed.
ValueCloningError = 2
The value cloning failed.
OtherError = 3
Other error. Either due to allocator failure or other unexpected error.